@@ -5,8 +5,5 @@
 static const constexpr clap_version m = CLAP_VERSION;
 
 int main(int, char **) {
-   clap_param_info param_info;
-   param_info.module[0] = 'm';
-
    return !clap_version_is_compatible(m);
 }
\ No newline at end of file
